@@ -91,4 +91,4 @@ class PaddleOCR(OCRInstance):
 
                 list_elements.append(dict_word)
 
-        return OCRDataframe(df=pl.from_dicts(list_elements).lazy()) if list_elements else None
+        return OCRDataframe(df=pl.LazyFrame(list_elements)) if list_elements else None
