@@ -60,7 +60,7 @@ def test_paddle_ocr_df():
 
     result = instance.to_ocr_dataframe(content=content)
 
-    expected = OCRDataframe(df=pl.read_csv("test_data/ocr_df.csv", sep=";").lazy())
+    expected = OCRDataframe(df=pl.read_csv("test_data/ocr_df.csv", separator=";").lazy())
 
     assert result == expected
 
@@ -74,6 +74,6 @@ def test_paddle_document():
 
     result = instance.of(document=doc)
 
-    expected = OCRDataframe(df=pl.read_csv("test_data/ocr_df.csv", sep=";").lazy())
+    expected = OCRDataframe(df=pl.read_csv("test_data/ocr_df.csv", separator=";").lazy())
 
     assert result == expected
